function [ kt ] = Stress_Step_Torsion( Big_Dia, Small_Dia, Fillet )
%
%  This routine computes the stress concentration factor for an torsional load
%  on a circular shaft with a diameter change.  Values are taken from
%  page 1029, Figure C-3 in Norton
%
%      Big_Dia = the larger diameter
%      Small_Dia = the smaller diameter
%      Fillet = the radius of the fillet at the step

Dt = [2.0 1.33 1.20 1.09]';
At = [.86331 .84897 .83425 .90337]';
bt = [-.23865 -.23161 -.21649 -.12692]';

%  Compute the diameter ratio and then interpolate A and b from the tables

D = Big_Dia / Small_Dia;

if (D > Dt(1)) 
    D = Dt(1);
end

if (D < Dt(4))
    D = Dt(4);
end

A = interp1 (Dt, At, D);
b = interp1 (Dt, bt, D);

%  Compute the stress concentration factor

kt = A * (Fillet / Small_Dia) ^ b;

end

